import hek

#hek.screen.screenshot(filename="hi.png")

'''
frame = hek.screen.screen_frame()
print(frame)
'''
'''
hek.screen.capture_video(filename="name.avi", seconds=3)
'''

#hek.webcam.webcamshot(filename="te.png")

#hek.webcam.capture_video(filename="webname.avi", seconds=3)